package
Version:
v1.1.0
Opens a new window with list of versions in this module.
Published: Jul 5, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Include []string `yaml:"include,omitempty"`
Transform []Transformable `yaml:"transform"`
}
type Transformable struct {
Target string `yaml:"target"`
If string `yaml:"if,omitempty"`
Value map[string]interface{} `yaml:"value,omitempty"`
ForEach string `yaml:"for_each,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.